@@ -1,18 +1,21 @@
+from datetime import datetime, timedelta
+
 import numpy as np
 import pandas as pd
-from datetime import datetime, timedelta
 from fbprophet import Prophet
 
 from tank_forecaster.decomp import (
-    generic_yearly_decomp,
-    generic_weekly_decomp,
-    generic_daily_decomp,
+    generic_hh_seasonality,
+    generic_weekly_seasonality,
+    generic_yearly_seasonality,
 )
 
 
 def gen_future(df, periods=30, freq="1D"):
     start_0 = df.iloc[-1, 0]
-    future = pd.date_range(start=start_0, freq=freq, periods=periods) + pd.Timedelta(freq)
+    future = pd.date_range(start=start_0, freq=freq, periods=periods) + pd.Timedelta(
+        freq
+    )
     future = pd.DataFrame(future)
     future.rename(columns={0: "ds"}, inplace=True)
 
@@ -93,7 +96,7 @@ def forecast_near(
 
     # less than 9 days of historical data
     if validated_tank_history is None:
-        validated_tank_history = pd.DataFrame(columns=['ds', 'y'])
+        validated_tank_history = pd.DataFrame(columns=["ds", "y"])
 
     if len(validated_tank_history) < 432:
 
@@ -168,4 +171,3 @@ def forecast_near(
         output.loc[output[field] < 0, field] = 0
 
     return output
-
